ControlCodec

Struct ControlCodec 

pub struct ControlCodec<EncodeDst: VoicePacketDst, DecodeDst: VoicePacketDst> { /* private fields */ }
A Codec implementation that parses a stream of data into ControlPackets.

Since VoicePackets can be tunneled over the control channel and their encoding and decoding depends on their destination, the control codec also needs to know the side it’s on. See ServerControlCodec and ClientControlCodec for the two most reasonable configurations.

Implementations

Source

impl<EncodeDst: VoicePacketDst, DecodeDst: VoicePacketDst> ControlCodec<EncodeDst, DecodeDst>

pub fn new() -> Self

Creates a new control codec.