Module ping

Module ping 

Ping messages and codec

A Mumble client can send periodic UDP PingPackets to servers in order to query their current state and measure latency. A server will usually respond with a corresponding PongPacket containing the requested details.

Both packets are of fixed size and can be converted to/from u8 arrays/slices via the respective From/TryFrom impls.

Structs

PingPacket
A ping packet sent to the server.
PongPacket
A pong packet sent to the client in reply to a previously received PingPacket.

Enums

ParsePingError
Error during parsing of a PingPacket.
ParsePongError
Error during parsing of a PongPacket.