[][src]Struct mumble_protocol::ping::PongPacket

pub struct PongPacket {
    pub id: u64,
    pub version: u32,
    pub users: u32,
    pub max_users: u32,
    pub bandwidth: u32,
}

A pong packet sent to the client in reply to a previously received PingPacket.

Fields

id: u64

Opaque, client-generated id.

Should match the value in the corresponding PingPacket.

version: u32

Server version. E.g. 0x010300 for 1.3.0.

users: u32

Current amount of users connected to the server.

max_users: u32

Configured limit on the amount of users which can be connected to the server.

bandwidth: u32

Maximum bandwidth for server-bound speech per client in bits per second