VoiceCodec

Struct VoiceCodec 

pub struct VoiceCodec<EncodeDst: VoicePacketDst, DecodeDst: VoicePacketDst> { /* private fields */ }
A Codec implementation that parses a stream of data chunks into VoicePackets.

The encoding and decoding of voice packets depends on their destination. See ServerVoiceCodec and ClientVoiceCodec for the two most reasonable configurations.

Implementations

Source

impl<EncodeDst: VoicePacketDst, DecodeDst: VoicePacketDst> VoiceCodec<EncodeDst, DecodeDst>

pub fn new() -> Self

Creates a new control codec.