[−][src]Struct mumble_protocol::ping::PongPacket
A pong packet sent to the client in reply to a previously received PingPacket.
Fields
id: u64Opaque, client-generated id.
Should match the value in the corresponding PingPacket.
version: u32Server version. E.g. 0x010300 for 1.3.0.
users: u32Current amount of users connected to the server.
max_users: u32Configured limit on the amount of users which can be connected to the server.
bandwidth: u32Maximum bandwidth for server-bound speech per client in bits per second