pub struct VoiceCodec<EncodeDst: VoicePacketDst, DecodeDst: VoicePacketDst> { /* private fields */ }Expand description
A Codec implementation that parses a stream of data chunks into VoicePackets.
The encoding and decoding of voice packets depends on their destination. See ServerVoiceCodec and ClientVoiceCodec for the two most reasonable configurations.
Implementations
Sourceimpl<EncodeDst: VoicePacketDst, DecodeDst: VoicePacketDst> VoiceCodec<EncodeDst, DecodeDst>
impl<EncodeDst: VoicePacketDst, DecodeDst: VoicePacketDst> VoiceCodec<EncodeDst, DecodeDst>