[−][src]Struct mumble_protocol::voice::VoiceCodec
A Codec implementation that parses a stream of data chunks into VoicePackets.
The encoding and decoding of voice packets depends on their destination. See ServerVoiceCodec and ClientVoiceCodec for the two most reasonable configurations.
Implementations
impl<EncodeDst: VoicePacketDst, DecodeDst: VoicePacketDst> VoiceCodec<EncodeDst, DecodeDst>[src]